@@ -1,7 +1,6 @@
 
 ;;; aspectj4emacs site-lisp configuration
-
-(setq load-path (cons "@SITELISP@" load-path))
+(add-to-list 'load-path "@SITELISP@")
 (require 'aspectj-mode)
 (require 'ajdee)
  
