@@ -2,5 +2,4 @@
 ;;; howm site-lisp configuration
 
 (add-to-list 'load-path "@SITELISP@")
-(require 'howm-mode)
-
+(autoload 'howm-menu "howm" nil t)
