@@ -1,7 +1,7 @@
 
-;;; Wanderlust site-lisp configuration
+;;; wanderlust site-lisp configuration
 
-(setq load-path (cons "/usr/share/emacs/site-lisp/wl" load-path))
+(add-to-list 'load-path "@SITELISP@")
 
 (autoload 'wl "wl" "Wanderlust" t)
 (autoload 'wl-other-frame "wl" "Wanderlust on new frame." t)
