@@ -1,4 +1,4 @@
-# $Header: /var/cvsroot/gentoo-x86/media-plugins/vdr-burn/files/rc-addon-0.0.9.sh,v 1.1 2006/05/21 12:36:33 hd_brummy Exp $
+# $Header: /var/cvsroot/gentoo-x86/media-plugins/vdr-burn/files/rc-addon-0.0.9.sh,v 1.2 2007/04/17 12:40:40 zzam Exp $
 #
 # rc-addon-script for plugin burn
 #
@@ -11,10 +11,10 @@ plugin_pre_vdr_start() {
 
 add_plugin_param "-d ${BURN_DATADIR}"
 
-if [[ ! -f /usr/bin/burnmark.sh ]] ; then
+if [ ! -f /usr/bin/burnmark.sh ] ; then
 
   # works on burn-0.0.5
-  if [[ ${BURN_CREATEONLY_ISO:=no} == "yes" ]] ; then
+  if [ "${BURN_CREATEONLY_ISO:=no}" = "yes" ] ; then
     add_plugin_param "-i ${BURN_ISODIR}"
   else
     add_plugin_param "-D ${BURN_DVDWRITER}"
@@ -29,9 +29,4 @@ else
 fi
 
 }
-
-# for compatibility
-if [[ ${SCRIPT_API:-1} -lt 2 ]]; then
-  plugin_pre_vdr_start
-fi
  		 
