@@ -1,4 +1,4 @@
-# $Header: /var/cvsroot/gentoo-x86/media-plugins/vdr-loadepg/files/rc-addon.sh,v 1.1 2006/08/12 19:31:21 hd_brummy Exp $
+# $Header: /var/cvsroot/gentoo-x86/media-plugins/vdr-loadepg/files/rc-addon.sh,v 1.2 2007/04/17 12:44:16 zzam Exp $
 #
 # rc-addon-script for plugin loadepg
 #
@@ -12,8 +12,4 @@ plugin_pre_vdr_start() {
 
 	add_plugin_param "-c ${LOADEPG_CONFDIR}"
 }
-		
-# for compatibility
-if [[ ${SCRIPT_API:-1} -lt 2 ]]; then
-	plugin_pre_vdr_start
-fi
\ No newline at end of file
+
