@@ -1,4 +1,4 @@
-# $Header: /var/cvsroot/gentoo-x86/media-plugins/vdr-mplayer/files/rc-addon.sh,v 1.1 2006/01/08 21:37:58 hd_brummy Exp $
+# $Header: /var/cvsroot/gentoo-x86/media-plugins/vdr-mplayer/files/rc-addon.sh,v 1.2 2007/04/17 12:50:07 zzam Exp $
 #
 # rc-addon plugin-startup-skript for vdr-mplayer
 #
@@ -12,9 +12,3 @@ plugin_pre_vdr_start() {
     add_plugin_param "-M ${MPLAYER_PLUGIN_CALL}"
 				
 }
-
-		
-# for compatibility
-	if [[ ${SCRIPT_API:-1} -lt 2 ]]; then
-      plugin_pre_vdr_start
-	fi
