@@ -1,4 +1,4 @@
-# $Header: /var/cvsroot/gentoo-x86/media-plugins/vdr-skinsoppalusikka/files/rc-addon-1.0.2.sh,v 1.2 2006/09/29 21:51:58 hd_brummy Exp $
+# $Header: /var/cvsroot/gentoo-x86/media-plugins/vdr-skinsoppalusikka/files/rc-addon-1.0.2.sh,v 1.3 2007/04/17 12:44:48 zzam Exp $
 #
 # rc-addon plugin-startup-skript for vdr-skinsoppalusikka
 #
@@ -9,7 +9,7 @@
 
 plugin_pre_vdr_start() {
 
-	if [[ ${PLUGINS} != ${PLUGINS/dxr3/} ]] ; then
+	if [ "${PLUGINS}" != "${PLUGINS#*dxr3}" ] ; then
 		: ${SKINSOPPALUSIKKA_LOGOS_DIR:=/usr/share/vdr/skinsoppalusikka/logos-dxr3}
 	else
 		: ${SKINSOPPALUSIKKA_LOGOS_DIR:=/usr/share/vdr/channel-logos}
@@ -18,9 +18,3 @@ plugin_pre_vdr_start() {
 	add_plugin_param "-l ${SKINSOPPALUSIKKA_LOGOS_DIR}"
 
 }
-
-# for compatibility
-if [[ ${SCRIPT_API:-1} -lt 2 ]]; then
-    plugin_pre_vdr_start
-fi
- 
