@@ -1,6 +1,6 @@
 #!/bin/sh
 #
-# $Header: /var/cvsroot/gentoo-x86/media-tv/vdr-dvd-scripts/files/0.0.2/dvdchanger_writedvd.sh,v 1.1 2006/07/09 14:20:32 zzam Exp $
+# $Header: /var/cvsroot/gentoo-x86/media-tv/vdr-dvd-scripts/files/0.0.3/dvdchanger_writedvd.sh,v 1.1 2007/07/21 22:40:13 hd_brummy Exp $
 #
 # 04 Mar 2006; Joerg Bornkessel <hd_brummy@gentoo.org>
 # addaptded to gentoo-vdr-scripts
@@ -21,10 +21,16 @@ ISO_FILE="${1// IMAGE/}"
 
 : ${VDR_DVDWRITER:=/dev/dvd}
 
+[[ -e /etc/conf.d/vdr.dvdswitch ]] && source /etc/conf.d/vdr.dvdswitch
+: ${DVDSWITCH_BURNSPEED:=0}
+
+
 DVD_RECORDCMD="growisofs"
-DVDPLUS_RECORD_OPTS="-use-the-force-luke=tty -dvd-compat -Z"
+DVDPLUS_RECORD_OPTS="-use-the-force-luke=tty -speed=$DVDSWITCH_BURNSPEED -dvd-compat -Z"
+
 
 unset SUDO_COMMAND
+
 svdrpsend.pl -d localhost "MESG DVD burn initiated"
 "$DVD_RECORDCMD" $DVDPLUS_RECORD_OPTS "$VDR_DVDWRITER"="${ISO_FILE}"
 svdrpsend.pl -d localhost "MESG DVD burn completed"
